@@ -9,10 +9,10 @@ N <- 100
 x <- matrix((1:N) + N * .comm.rank, ncol = 10)
 comm.print(x)
 
-y <- pbdApply(x, 1, sum, pbd.mode = "spmd")
+y <- pbdApply(x, 1, sum, pbd.mode = "mw")
 comm.print(y)
 
-y <- pbdApply(x, 1, sum)
+y <- pbdApply(x, 1, sum, pbd.mode = "spmd")
 comm.print(y)
 
 finalize()
